@@ -322,7 +322,7 @@ static int __init snd_card_ad1816a_probe(int dev,
 
 	if (snd_ad1816a_new_pcm(card, 0, snd_port[dev],
 			acard->irqptr, acard->dma1ptr, acard->dma2ptr,
-			&pcm) < 0)
+			0, &pcm) < 0)
 		goto __on_error;
 
 	codec = snd_magic_cast(ad1816a_t, pcm->private_data, -ENXIO);
