@@ -623,16 +623,7 @@ static int __init snd_card_cs4236_probe(int dev, struct snd_card_cs4236 *acard)
 	return -ENXIO;
 }
 
-#ifdef MODULE
-int __init init_module(void)
-#else
-#ifdef CS4232
-int __init alsa_card_cs4232_init(void)
-#endif
-#ifdef CS4236
-int __init alsa_card_cs4236_init(void)
-#endif
-#endif
+static int __init alsa_card_cs423x_init(void)
 {
 	int dev, cards;
 	struct snd_card_cs4236 *acard;
@@ -667,9 +658,7 @@ int __init alsa_card_cs4236_init(void)
 	return 0;
 }
 
-#ifdef MODULE
-
-void __exit cleanup_module(void)
+static void __exit alsa_card_cs423x_exit(void)
 {
 	int idx;
 	struct snd_card_cs4236 *acard;
@@ -686,4 +675,5 @@ void __exit cleanup_module(void)
 	}
 }
 
-#endif
+module_init(alsa_card_cs423x_init)
+module_exit(alsa_card_cs423x_exit)
