@@ -957,11 +957,7 @@ static int __init snd_opl3sa_probe(int dev, struct snd_opl3sa *oplcard)
 	return -ENXIO;
 }
 
-#ifdef MODULE
-int __init init_module(void)
-#else
-int __init alsa_card_opl3sa2_init(void)
-#endif
+static int __init alsa_card_opl3sa2_init(void)
 {
 	int dev, cards;
 	struct snd_opl3sa *oplcard;
@@ -971,7 +967,7 @@ int __init alsa_card_opl3sa2_init(void)
 				snd_kcalloc(sizeof(struct snd_opl3sa), GFP_KERNEL);
 		if (oplcard == NULL)
 			continue;
-		oplcard->reg_lock = SPIN_LOCK_UNLOCKED;
+		spin_lock_init(&oplcard->reg_lock);
 		if (snd_opl3sa_probe(dev, oplcard) < 0) {
 #ifdef __ISAPNP__
 			snd_opl3sa_deactivate(oplcard);
@@ -996,9 +992,7 @@ int __init alsa_card_opl3sa2_init(void)
 	return 0;
 }
 
-#ifdef MODULE
-
-void __exit cleanup_module(void)
+static void __exit alsa_card_opl3sa2_exit(void)
 {
 	int idx;
 	struct snd_opl3sa *oplcard;
@@ -1015,4 +1009,5 @@ void __exit cleanup_module(void)
 	}
 }
 
-#endif
+module_init(alsa_card_opl3sa2_init)
+module_exit(alsa_card_opl3sa2_exit)
