@@ -219,7 +219,7 @@ static void mix(snd_pcm_subchn_t *subchn, snd_card_share_pcm_open_t *pcmo,
 			subchns++;
 		}
 		if (subchns == 0) {
-			memset(dst, snd_pcm_lib_silence(subchn), STEP);
+			memset(dst, snd_pcm_format_silence(subchn->runtime->format.format), STEP);
 		} else {
 			s = pcmo->share->mix_buf;
 			d = (short*) dst;
@@ -299,7 +299,7 @@ static void cdivide(snd_pcm_subchn_t *subchn, snd_card_share_pcm_open_t *pcmo, i
 		dst = druntime->dma_area->buf;
 		dst += (*druntime->frag_head % druntime->frags) * druntime->buf.block.frag_size;
 		if (dpcm->mix == NULL || dpcm->mix->zero) {
-			memset(dst, snd_pcm_lib_silence(dpcm->subchn), count);
+			memset(dst, snd_pcm_format_silence(druntime->format.format), count);
 		} else {
 			cdivide1(dpcm, (short *)dst, (short *)src, count / SHARE_SAMPLE_SIZE);
 		}
@@ -474,7 +474,7 @@ static int snd_card_share_playback_prepare(void *private_data,
 		druntime = dsubchn->runtime;
 		if (druntime->dma_area == NULL)
 			return -EIO;		/* TODO */
-		silence = snd_pcm_lib_silence(dsubchn);
+		silence = snd_pcm_format_silence(druntime->format.format);
 		memset(druntime->dma_area->buf, silence, druntime->buf.block.frag_size + 128);
 	}
 	return 0;
