@@ -59,6 +59,10 @@ MODULE_PARM_DESC(snd_fm_frame_size, "FM playback frame size in kB.");
  *  Direct registers
  */
 
+#ifndef PCI_DEVICE_ID_VIA_82C686_5
+#define PCI_DEVICE_ID_VIA_82C686_5	0x3058
+#endif
+
 #define VIAREG(via, x) ((via)->port + VIA_REG_##x)
 
 /* offsets */
@@ -199,7 +203,7 @@ static inline void snd_via686a_codec_xwrite(via686a_t *codec, unsigned int val)
 	outw((unsigned short)(val >> 16), VIAREG(codec, AC97) + 2);
 }
  
-static int snd_via686a_codec_ready(via686a_t *codec, int secondary)
+static int snd_via686a_codec_ready(via686a_t *codec, int secondary, int sched)
 {
 	signed long end_time;
 	unsigned int val;
@@ -208,6 +212,10 @@ static int snd_via686a_codec_ready(via686a_t *codec, int secondary)
 	do {
 		if (!((val = snd_via686a_codec_xread(codec)) & VIA_REG_AC97_BUSY))
 			return val & 0xffff;
+		if (sched) {
+			set_current_state(TASK_UNINTERRUPTIBLE);
+			schedule_timeout(1);
+		}
 	} while (end_time - (signed long)jiffies >= 0);
 	snd_printk("snd_via686a_codec_ready: codec %i is not ready [0x%x]\n", secondary, snd_via686a_codec_xread(codec));
 	return -EIO;
@@ -230,13 +238,13 @@ static int snd_via686a_codec_valid(via686a_t *codec, int secondary)
 }
  
 static void snd_via686a_codec_write(void *private_data,
-				     unsigned short reg,
-				     unsigned short val)
+				    unsigned short reg,
+				    unsigned short val)
 {
 	via686a_t *codec = (via686a_t *)private_data;
 	unsigned int xval;
 	
-	snd_via686a_codec_ready(codec, 0);
+	snd_via686a_codec_ready(codec, 0, 0);
 	xval = 0 << VIA_REG_AC97_CODEC_ID_SHIFT;
 	xval |= VIA_REG_AC97_PRIMARY_VALID;
 	xval |= reg << VIA_REG_AC97_CMD_SHIFT;
@@ -250,14 +258,14 @@ static unsigned short snd_via686a_codec_read(void *private_data,
 	via686a_t *codec = (via686a_t *)private_data;
 	unsigned int xval;
 
-	if (snd_via686a_codec_ready(codec, 0) < 0)
+	if (snd_via686a_codec_ready(codec, 0, 0) < 0)
 		return ~0;
 	xval = 0 << VIA_REG_AC97_CODEC_ID_SHIFT;
 	xval |= VIA_REG_AC97_PRIMARY_VALID;
 	xval |= VIA_REG_AC97_READ;
 	xval |= reg << VIA_REG_AC97_CMD_SHIFT;
 	snd_via686a_codec_xwrite(codec, xval);
-	if (snd_via686a_codec_ready(codec, 0) < 0)
+	if (snd_via686a_codec_ready(codec, 0, 0) < 0)
 		return ~0;
 	if (snd_via686a_codec_valid(codec, 0) < 0)
 		return ~0;
@@ -946,10 +954,13 @@ static int snd_via686a_chip_init(via686a_t *codec)
 	/* deassert ACLink reset, force SYNC (warm AC'97 reset) */
 	pci_write_config_byte(codec->pci, 0x41, 0x60);
 	udelay(2);
-	/* ACLink on, deassert ACLink reset, VSR, SGD + FM data out */
-	pci_write_config_byte(codec->pci, 0x41, 0xce);
+	/* ACLink on, deassert ACLink reset, VSR, SGD data out */
+	/* not FM data out has trouble with non VRA codecs !! */
+	pci_write_config_byte(codec->pci, 0x41, 0xcc);
 
+	snd_via686a_codec_ready(codec, 0, 1);
 	snd_via686a_codec_write(codec, AC97_POWERDOWN, 0x0000);
+	snd_via686a_codec_ready(codec, 0, 1);
 
 #if 0
 	{
@@ -1152,7 +1163,6 @@ static int __init snd_via686a_probe(int dev, via686a_card_t *scard)
 			    snd_via686a_use_inc, snd_via686a_use_dec);
 	if (card == NULL)
 		return -ENOMEM;
-	card->static_data = scard;
 	card->type = SND_CARD_TYPE_VIA82C686A;
 	do {
 		if (!snd_via686a_detect(card, scard, PCI_VENDOR_ID_VIA, PCI_DEVICE_ID_VIA_82C686_5))
