@@ -121,7 +121,7 @@ typedef struct snd_switch {
 		unsigned short data16[16];	/* 16-bit data */
 		unsigned int data32[8];		/* 32-bit data */
 		int item_number;		/* active list item number */
-		char item[32];			/* list item, low=high -> item number */
+		char item[32];			/* list item, low -> item number */
 	} value;
 	unsigned char reserved[32];
 } snd_switch_t;
