@@ -47,20 +47,20 @@
 #include <linux/config.h>
 #include <linux/version.h>
 
-#if KERNEL_VERSION(2, 2, 3) > LINUX_VERSION_CODE
-#error "This driver requires Linux 2.2.3 and highter."
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 2, 3)
+#error "This driver requires Linux 2.2.3 and higher."
 #endif
-#if KERNEL_VERSION(2, 2, 0) <= LINUX_VERSION_CODE
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 2, 0)
 #define LINUX_2_2
 #endif
-#if KERNEL_VERSION(2, 3, 1) <= LINUX_VERSION_CODE
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 3, 1)
 #define LINUX_2_3
 #endif
-#if KERNEL_VERSION(2, 3, 11) <= LINUX_VERSION_CODE
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 3, 11)
 #define NEW_RESOURCE
 #endif
-#if defined(LINUX_2_3) && KERNEL_VERSION(2, 3, 48) > LINUX_VERSION_CODE
-#error "This driver requires Linux 2.3.48 and highter."
+#if defined(LINUX_2_3) && LINUX_VERSION_CODE < KERNEL_VERSION(2, 3, 48)
+#error "This driver requires Linux 2.3.48 and higher."
 #endif
 
 #ifdef ALSA_BUILD
@@ -112,10 +112,12 @@
 #endif
 #ifdef LINUX_2_3
 #include <linux/init.h>
+#define PCI_GET_DRIVER_DATA(pci) pci->driver_data
+#define PCI_SET_DRIVER_DATA(pci, data) pci->driver_data = data
 #endif
 
 #if defined(CONFIG_ISAPNP) || (defined(CONFIG_ISAPNP_MODULE) && defined(MODULE))
-#if (defined(CONFIG_ISAPNP_KERNEL) && defined(ALSA_BUILD)) || (KERNEL_VERSION(2, 3, 30) <= LINUX_VERSION_CODE && !defined(ALSA_BUILD))
+#if (defined(CONFIG_ISAPNP_KERNEL) && defined(ALSA_BUILD)) || (LINUX_VERSION_CODE >= KERNEL_VERSION(2, 3, 30) && !defined(ALSA_BUILD))
 #include <linux/isapnp.h>
 #define isapnp_dev pci_dev
 #define isapnp_card pci_bus
@@ -303,9 +305,7 @@ struct snd_stru_card {
 	struct semaphore control;		/* control card mutex */
 
 	void *private_data;			/* private data for soundcard */
-	void (*private_free) (void *private);	/* callback for freeing of private data */
-
-	void *static_data;			/* private static data for soundcard */
+	void (*private_free) (void *private_data); /* callback for freeing of private data */
 
 	snd_device_t *devices;			/* devices */
 
