@@ -100,7 +100,7 @@ static int snd_mixer_release(unsigned short minor, int cardnum, int device,
 		spin_lock_irqsave(&mixer->ffile_lock, flags);
 		while (mfile->use) {
 			spin_unlock_irqrestore(&mixer->ffile_lock, flags);
-			current->state = TASK_INTERRUPTIBLE;
+			set_current_state(TASK_INTERRUPTIBLE);
 			schedule_timeout(1);
 			spin_lock_irqsave(&mixer->ffile_lock, flags);
 		}
