@@ -120,53 +120,12 @@ unsigned int snd_pcm_lib_transfer_fragment(snd_pcm_subchn_t *subchn)
 	return 0;
 }
 
-int snd_pcm_lib_neutral_byte(snd_pcm_subchn_t *subchn)
-{
-	if (snd_pcm_format_unsigned(subchn->runtime->format.format))
-		return 0x80;
-	return 0x00;
-}
-
 int snd_pcm_lib_interleave_len(snd_pcm_subchn_t *subchn)
 {
 	return snd_pcm_format_size(subchn->runtime->format.format,
 				   subchn->runtime->format.voices);
 }
 
-unsigned char snd_pcm_lib_silence(snd_pcm_subchn_t *subchn)
-{
-	switch (subchn->runtime->format.format) {
-	case SND_PCM_SFMT_IMA_ADPCM:	/* special case */
-	case SND_PCM_SFMT_MPEG:
-	case SND_PCM_SFMT_GSM:
-	case SND_PCM_SFMT_MU_LAW:
-	case SND_PCM_SFMT_A_LAW:
-		return 0;
-	case SND_PCM_SFMT_U8:
-	case SND_PCM_SFMT_U16_LE:
-	case SND_PCM_SFMT_U16_BE:
-	case SND_PCM_SFMT_U24_LE:
-	case SND_PCM_SFMT_U24_BE:
-	case SND_PCM_SFMT_U32_LE:
-	case SND_PCM_SFMT_U32_BE:
-		return 0x80;
-	case SND_PCM_SFMT_S8:
-	case SND_PCM_SFMT_S16_LE:
-	case SND_PCM_SFMT_S16_BE:
-	case SND_PCM_SFMT_S24_LE:
-	case SND_PCM_SFMT_S24_BE:
-	case SND_PCM_SFMT_S32_LE:
-	case SND_PCM_SFMT_S32_BE:
-		return 0;
-	case SND_PCM_SFMT_FLOAT:
-	case SND_PCM_SFMT_FLOAT64:
-	case SND_PCM_SFMT_IEC958_SUBFRAME_LE:
-	case SND_PCM_SFMT_IEC958_SUBFRAME_BE:
-		return 0;	
-	}
-	return 0;
-}
-
 /*
  *  Standard ioctl routine
  */
@@ -1070,7 +1029,7 @@ static int snd_pcm_lib_fill(snd_pcm_subchn_t *subchn, unsigned int ptr,
 	unsigned long flags;
 	
 	spin_lock_irqsave(&runtime->lock, flags);
-	silencebyte = snd_pcm_lib_silence(subchn);
+	silencebyte = snd_pcm_format_silence(runtime->format.format);
 	if (runtime->fill_position < runtime->position)
 		runtime->fill_position = runtime->position;
 	xfree = (ptr + runtime->buf.stream.queue_size) - runtime->position;
@@ -1357,7 +1316,7 @@ static int snd_pcm_lib_writev_transfer(snd_pcm_subchn_t *subchn,
 		snd_debug_check(runtime->hw_memset == NULL, -EINVAL);
 		for (v = 0; v < voices; ++v) {
 			if (bufs[v] == NULL) {
-				if ((err = runtime->hw_memset(subchn, v, dstoff, snd_pcm_lib_silence(subchn), size)) < 0)
+				if ((err = runtime->hw_memset(subchn, v, dstoff, snd_pcm_format_silence(runtime->format.format), size)) < 0)
 					return err;
 				snd_pcm_proc_write_silence(subchn, runtime->position, size);
 			} else {
@@ -1372,7 +1331,7 @@ static int snd_pcm_lib_writev_transfer(snd_pcm_subchn_t *subchn,
 		for (v = 0; v < voices; ++v) {
 			char *dest = runtime->dma_area->buf + (v * buf_size) + dstoff;
 			if (bufs[v] == NULL) {
-				memset(dest, snd_pcm_lib_silence(subchn), size);
+				memset(dest, snd_pcm_format_silence(runtime->format.format), size);
 				snd_pcm_proc_write_silence(subchn, runtime->position, size);
 			} else {
 				if (copy_from_user(dest, bufs[v] + srcoff, size))
@@ -1786,7 +1745,6 @@ EXPORT_SYMBOL(snd_pcm_set_sync);
 EXPORT_SYMBOL(snd_pcm_set_mixer);
 EXPORT_SYMBOL(snd_pcm_lib_transfer_size);
 EXPORT_SYMBOL(snd_pcm_lib_transfer_fragment);
-EXPORT_SYMBOL(snd_pcm_lib_silence);
 EXPORT_SYMBOL(snd_pcm_lib_interleave_len);
 EXPORT_SYMBOL(snd_pcm_lib_set_buffer_size);
 EXPORT_SYMBOL(snd_pcm_lib_mmap_ctrl_ptr);
