@@ -370,7 +370,7 @@ static int snd_pcm_playback_flush(snd_pcm_subchn_t * subchn)
 					return -EIO;
 				}
 			} else if (runtime->mode == SND_PCM_MODE_STREAM) {
-				current->state = TASK_INTERRUPTIBLE;
+				set_current_state(TASK_INTERRUPTIBLE);
 				schedule_timeout(1);
 				if (signal_pending(current)) {
 					runtime->stop_mode = stop_mode;
@@ -879,7 +879,7 @@ static int snd_pcm_mmap(struct inode *inode, struct file *file,
 	if (*runtime->status != SND_PCM_STATUS_READY)
 		return -EBADFD;
 	size = area->vm_end - area->vm_start;
-#if KERNEL_VERSION(2, 3, 25) <= LINUX_VERSION_CODE
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 3, 25)
 	switch (area->vm_pgoff << PAGE_SHIFT) {
 #else
 	switch (area->vm_offset) {
