@@ -175,18 +175,23 @@ int snd_rawmidi_kernel_open(int cardnum, int device, int mode, snd_rawmidi_t **
 		err = -ENXIO;
 		goto _err;
 	}
-	if ((mode & (SND_RAWMIDI_LFLG_OUTPUT | SND_RAWMIDI_LFLG_APPEND)) ==
-		    (SND_RAWMIDI_LFLG_OUTPUT | SND_RAWMIDI_LFLG_APPEND)) {
-		if (rmidi->flags & (mode & SND_RAWMIDI_LFLG_INPUT)) {
-			err = -EAGAIN;
-			goto _err;
-		}
-		if (rmidi->flags & SND_RAWMIDI_LFLG_OUTPUT)
-			if (!(rmidi->flags & SND_RAWMIDI_LFLG_APPEND)) {
+	if (mode & SND_RAWMIDI_LFLG_APPEND) {
+		if (mode & SND_RAWMIDI_LFLG_OUTPUT) {
+			if (rmidi->flags & SND_RAWMIDI_LFLG_OUTPUT)
+				if (!(rmidi->flags & SND_RAWMIDI_LFLG_APPEND)) {
+					err = -EAGAIN;
+					goto _err;
+				}
+			if (rmidi->flags & (mode & SND_RAWMIDI_LFLG_INPUT)) {
 				err = -EAGAIN;
 				goto _err;
 			}
+		} else {
+			mode &= ~SND_RAWMIDI_LFLG_APPEND;
+			goto _std;
+		}
 	} else {
+	       _std:
 		if (rmidi->flags & mode) {
 			err = -EAGAIN;
 			goto _err;
@@ -312,7 +317,7 @@ int snd_rawmidi_kernel_info(int cardnum, int device, snd_rawmidi_info_t *info)
 	rmidi = snd_rawmidi_devices[(cardnum * SND_RAWMIDI_DEVICES) + device];
 	if (rmidi == NULL)
 		return -ENODEV;
-	memset(info, 0, sizeof(info));
+	memset(info, 0, sizeof(*info));
 	info->type = rmidi->card->type;
 	info->flags = rmidi->info_flags;
 	strcpy(info->id, rmidi->id);
@@ -390,7 +395,7 @@ static int snd_rawmidi_output_status(snd_rawmidi_t * rmidi,
 	snd_rawmidi_channel_t *pchn;
 
 	pchn = &rmidi->chn[SND_RAWMIDI_CHANNEL_OUTPUT];
-	memset(status, 0, sizeof(status));
+	memset(status, 0, sizeof(*status));
 	status->channel = SND_RAWMIDI_CHANNEL_OUTPUT;
 	spin_lock_irqsave(&pchn->lock, flags);
 	status->size = pchn->size;
@@ -407,7 +412,7 @@ static int snd_rawmidi_input_status(snd_rawmidi_t * rmidi,
 	snd_rawmidi_channel_t *pchn;
 
 	pchn = &rmidi->chn[SND_RAWMIDI_CHANNEL_INPUT];
-	memset(status, 0, sizeof(status));
+	memset(status, 0, sizeof(*status));
 	status->channel = SND_RAWMIDI_CHANNEL_INPUT;
 	spin_lock_irqsave(&pchn->lock, flags);
 	status->size = pchn->size;
@@ -585,7 +590,7 @@ void snd_rawmidi_receive_reset(snd_rawmidi_t * rmidi)
 	/* TODO: reset current state */
 }
 
-int snd_rawmidi_receive(snd_rawmidi_t * rmidi, char *buffer, int count)
+int snd_rawmidi_receive(snd_rawmidi_t * rmidi, unsigned char *buffer, int count)
 {
 	unsigned long flags;
 	int result = 0, count1;
@@ -593,33 +598,45 @@ int snd_rawmidi_receive(snd_rawmidi_t * rmidi, char *buffer, int count)
 	pchn = &rmidi->chn[SND_RAWMIDI_CHANNEL_INPUT];
 
 	if (pchn->buffer == NULL) {
-		snd_printd("snd_rawmidi_receive: input isn't active!!!\n");
+		snd_printd("snd_rawmidi_receive: input is not active!!!\n");
 		return -EINVAL;
 	}
 	spin_lock_irqsave(&pchn->lock, flags);
-	pchn->bytes += count;
-	count1 = pchn->size - pchn->head;
-	if (count1 > count)
-		count1 = count;
-	if (count1 > pchn->size - pchn->used)
-		count1 = pchn->size - pchn->used;
-	memcpy(pchn->buffer + pchn->head, buffer, count1);
-	pchn->head += count1;
-	pchn->head %= pchn->size;
-	pchn->used += count1;
-	count -= count1;
-	result += count1;
-	if (count > 0) {
-		count1 = count;
-		if (count > pchn->size - pchn->used) {
-			count1 = pchn->size - pchn->used;
-			pchn->xruns = count - count1;
+	if (count == 1) {	/* special case, faster code */
+		pchn->bytes++;
+		if (pchn->used < pchn->size) {
+			pchn->buffer[pchn->head++] = buffer[0];
+			pchn->head %= pchn->size;
+			pchn->used++;
+			result++;
+		} else {
+			pchn->xruns++;
 		}
-		if (count1 > 0) {
-			memcpy(pchn->buffer, buffer + count1, count1);
-			pchn->head = count1;
-			pchn->used += count1;
-			result += count1;
+	} else {
+		pchn->bytes += count;
+		count1 = pchn->size - pchn->head;
+		if (count1 > count)
+			count1 = count;
+		if (count1 > pchn->size - pchn->used)
+			count1 = pchn->size - pchn->used;
+		memcpy(pchn->buffer + pchn->head, buffer, count1);
+		pchn->head += count1;
+		pchn->head %= pchn->size;
+		pchn->used += count1;
+		count -= count1;
+		result += count1;
+		if (count > 0) {
+			count1 = count;
+			if (count > pchn->size - pchn->used) {
+				count1 = pchn->size - pchn->used;
+				pchn->xruns = count - count1;
+			}
+			if (count1 > 0) {
+				memcpy(pchn->buffer, buffer + count1, count1);
+				pchn->head = count1;
+				pchn->used += count1;
+				result += count1;
+			}
 		}
 	}
 	spin_unlock_irqrestore(&pchn->lock, flags);
@@ -634,7 +651,7 @@ int snd_rawmidi_receive(snd_rawmidi_t * rmidi, char *buffer, int count)
 	return result;
 }
 
-static long snd_rawmidi_kernel_read1(snd_rawmidi_t *rmidi, char *buf, long count, int kernel)
+static long snd_rawmidi_kernel_read1(snd_rawmidi_t *rmidi, unsigned char *buf, long count, int kernel)
 {
 	unsigned long flags;
 	long result = 0, count1;
@@ -666,7 +683,7 @@ static long snd_rawmidi_kernel_read1(snd_rawmidi_t *rmidi, char *buf, long count
 	return result;
 }
 
-long snd_rawmidi_kernel_read(snd_rawmidi_t *rmidi, char *buf, long count)
+long snd_rawmidi_kernel_read(snd_rawmidi_t *rmidi, unsigned char *buf, long count)
 {
 	snd_rawmidi_channel_t *pchn;
 	
@@ -719,18 +736,18 @@ int snd_rawmidi_transmit_empty(snd_rawmidi_t * rmidi)
 
 	pchn = &rmidi->chn[SND_RAWMIDI_CHANNEL_OUTPUT];
 	if (pchn->buffer == NULL) {
-		snd_printd("snd_rawmidi_transmit_empty: output isn't active!!!\n");
+		snd_printd("snd_rawmidi_transmit_empty: output is not active!!!\n");
 		return 1;
 	}
 	spin_lock_irqsave(&pchn->lock, flags);
-	result = pchn->used > 0;
+	result = pchn->used <= 0;
 	if (result)
 		pchn->flags &= ~SND_RAWMIDI_FLG_TRIGGER;
 	spin_unlock_irqrestore(&pchn->lock, flags);
 	return result;		
 }
 
-int snd_rawmidi_transmit(snd_rawmidi_t * rmidi, char *buffer, int count)
+int snd_rawmidi_transmit(snd_rawmidi_t * rmidi, unsigned char *buffer, int count)
 {
 	unsigned long flags;
 	int result, count1;
@@ -738,34 +755,42 @@ int snd_rawmidi_transmit(snd_rawmidi_t * rmidi, char *buffer, int count)
 
 	pchn = &rmidi->chn[SND_RAWMIDI_CHANNEL_OUTPUT];
 	if (pchn->buffer == NULL) {
-		snd_printd("snd_rawmidi_transmit: output isn't active!!!\n");
+		snd_printd("snd_rawmidi_transmit: output is not active!!!\n");
 		return 0;
 	}
 	result = 0;
 	spin_lock_irqsave(&pchn->lock, flags);
-	count1 = pchn->size - pchn->tail;
-	if (count1 > count)
-		count1 = count;
-	if (count1 > pchn->used)
-		count1 = pchn->used;
-	if (!count1) {
+	if (pchn->used == 0) {
 		/* warning: lowlevel layer MUST trigger down the hardware */
 		pchn->flags &= ~SND_RAWMIDI_FLG_TRIGGER;
 		goto __skip;
 	}
-	memcpy(buffer, pchn->buffer + pchn->tail, count1);
-	pchn->tail += count1;
-	pchn->tail %= pchn->size;
-	pchn->used -= count1;
-	count -= count1;
-	result += count1;
-	if (count > 0) {
-		memcpy(buffer + count1, pchn->buffer, count);
-		pchn->tail = count;
-		pchn->used -= count;
-		result += count;
+	if (count == 1) {	/* special case, faster code */
+		buffer[0] = pchn->buffer[pchn->tail++];
+		pchn->tail %= pchn->size;
+		pchn->used--;
+		pchn->bytes++;
+		result++;
+	} else {
+		count1 = pchn->size - pchn->tail;
+		if (count1 > count)
+			count1 = count;
+		if (count1 > pchn->used)
+			count1 = pchn->used;
+		memcpy(buffer, pchn->buffer + pchn->tail, count1);
+		pchn->tail += count1;
+		pchn->tail %= pchn->size;
+		pchn->used -= count1;
+		count -= count1;
+		result += count1;
+		if (count > 0) {
+			memcpy(buffer + count1, pchn->buffer, count);
+			pchn->tail = count;
+			pchn->used -= count;
+			result += count;
+		}
+		pchn->bytes += result;
 	}
-	pchn->bytes += result;
       __skip:
 	spin_unlock_irqrestore(&pchn->lock, flags);
 	if (result > 0) {
@@ -782,7 +807,7 @@ int snd_rawmidi_transmit(snd_rawmidi_t * rmidi, char *buffer, int count)
 	return result;
 }
 
-static long snd_rawmidi_kernel_write1(snd_rawmidi_t * rmidi, const char *buf, long count, int kernel)
+static long snd_rawmidi_kernel_write1(snd_rawmidi_t * rmidi, const unsigned char *buf, long count, int kernel)
 {
 	unsigned long flags;
 	long count1, result;
@@ -826,7 +851,7 @@ static long snd_rawmidi_kernel_write1(snd_rawmidi_t * rmidi, const char *buf, lo
 	return result;
 }
 
-long snd_rawmidi_kernel_write(snd_rawmidi_t * rmidi, const char *buf, long count)
+long snd_rawmidi_kernel_write(snd_rawmidi_t * rmidi, const unsigned char *buf, long count)
 {
 	return snd_rawmidi_kernel_write1(rmidi, buf, count, 1);
 }
