@@ -115,7 +115,7 @@ void snd_seq_instr_list_free(snd_seq_kinstr_list_t **list_ptr)
 			spin_lock_irqsave(&list->lock, flags);
 			while (instr->use) {
 				spin_unlock_irqrestore(&list->lock, flags);
-				current->state = TASK_INTERRUPTIBLE;
+				set_current_state(TASK_INTERRUPTIBLE);
 				schedule_timeout(1);
 				spin_lock_irqsave(&list->lock, flags);
 			}				
@@ -206,7 +206,7 @@ int snd_seq_instr_list_free_cond(snd_seq_kinstr_list_t *list,
 			instr = flist;
 			flist = instr->next;
 			while (instr->use) {
-				current->state = TASK_INTERRUPTIBLE;
+				set_current_state(TASK_INTERRUPTIBLE);
 				schedule_timeout(1);
 			}				
 			if (snd_seq_instr_free(instr, atomic)<0)
@@ -585,7 +585,7 @@ static int instr_free(snd_seq_kinstr_ops_t *ops,
 			instr->ops->notify(instr->ops->private_data, instr, SND_SEQ_INSTR_NOTIFY_REMOVE);
 		while (instr->use) {
 			spin_unlock_irqrestore(&list->lock, flags);
-			current->state = TASK_INTERRUPTIBLE;
+			set_current_state(TASK_INTERRUPTIBLE);
 			schedule_timeout(1);
 			spin_lock_irqsave(&list->lock, flags);
 		}				
