@@ -27,7 +27,7 @@ void snd_seq_sleep_in_lock(wait_queue_head_t *p, spinlock_t *lock)
 {
 	wait_queue_t wait;
 
-	current->state = TASK_INTERRUPTIBLE;
+	set_current_state(TASK_INTERRUPTIBLE);
 	init_waitqueue_entry(&wait, current);
 
 	add_wait_queue(p, &wait);
@@ -43,7 +43,7 @@ long snd_seq_sleep_timeout_in_lock(wait_queue_head_t *p, spinlock_t *lock, long
 {
 	wait_queue_t wait;
 
-	current->state = TASK_INTERRUPTIBLE;
+	set_current_state(TASK_INTERRUPTIBLE);
 	init_waitqueue_entry(&wait, current);
 
 	add_wait_queue(p, &wait);
