@@ -703,18 +703,17 @@ void snd_midi_channel_free_set(snd_midi_channel_set_t *chset)
 	snd_kfree(chset);
 }
 
-#ifdef MODULE
-
-int __init init_module(void)
+static int __init alsa_seq_midi_emul_init(void)
 {
 	return 0;
 }
 
-void __exit cleanup_module(void)
+static void __exit alsa_seq_midi_emul_exit(void)
 {
 }
 
-#endif
+module_init(alsa_seq_midi_emul_init)
+module_exit(alsa_seq_midi_emul_exit)
 
 EXPORT_SYMBOL(snd_midi_process_event);
 EXPORT_SYMBOL(snd_midi_channel_set_clear);
