@@ -107,30 +107,38 @@ static inline int snd_virmidi_input_ok(snd_virmidi_t *rmidi)
 }
 
 /*
- * check if output buffer is writable -
- * since the current implementation use snd_seq_kernel_client_dispatch,
- * this always returns 1
+ * check if output buffer is writable
  */
 static inline int snd_virmidi_output_ok(snd_virmidi_t *rmidi)
 {
-	return 1;
+	unsigned long flags;
+	int result, free;
+	snd_virmidi_channel_t *pchn;
+
+	pchn = &rmidi->chn[SND_RAWMIDI_CHANNEL_OUTPUT];
+	spin_lock_irqsave(&pchn->lock, flags);
+	free = pchn->size - pchn->used;
+	result = rmidi->parser->qlen <= pchn->used_max &&
+		free >= pchn->used_room;
+	spin_unlock_irqrestore(&pchn->lock, flags);
+	return result;
 }
 
 /*
  * create input/output buffer -
  * only input buffer has really allocated buffer
  */
-static int snd_virmidi_init_buffer(snd_virmidi_t *rmidi, int channel)
+static int snd_virmidi_init_buffer(snd_virmidi_t *rmidi, int channel, int size, int alloc_buf)
 {
 	snd_virmidi_channel_t *pchn;
 	pchn = &rmidi->chn[channel];
 	/*pchn->event = NULL;*/
-	pchn->size = PAGE_SIZE;
+	pchn->size = size;
 	pchn->used_max = pchn->size - 1;
 	pchn->used_room = 1;
 	pchn->used_min = 1;
 	pchn->buffer = NULL;
-	if (channel == SND_RAWMIDI_CHANNEL_INPUT) {
+	if (alloc_buf) {
 		if ((pchn->buffer = snd_kmalloc(pchn->size, GFP_KERNEL)) == NULL) {
 			return -ENOMEM;
 		}
@@ -159,10 +167,10 @@ static int snd_virmidi_done_buffer(snd_virmidi_t *rmidi, int channel)
  */
 static int snd_virmidi_drain_output(snd_virmidi_t *rmidi)
 {
+	snd_virmidi_channel_t *pchn;
+	pchn = &rmidi->chn[SND_RAWMIDI_CHANNEL_OUTPUT];
 	snd_midi_event_reset_encode(rmidi->parser);
-	/*
-	pchn->used = pchn->head = pchn->tail = 0;
-	*/
+	pchn->used = 0;
 	return 0;
 }
 
@@ -204,6 +212,7 @@ static int snd_virmidi_open(unsigned short minor, int cardnum, int device,
 	snd_virmidi_dev_t *rdev;
 	snd_virmidi_t *rmidi;
 	snd_virmidi_channel_t *ichn, *ochn;
+	int obufsize;
 	unsigned long flags;
 
 	rdev = snd_virmidi_devices[(cardnum * SND_RAWMIDI_DEVICES) + device];
@@ -214,6 +223,8 @@ static int snd_virmidi_open(unsigned short minor, int cardnum, int device,
 		file->f_flags |= O_NONBLOCK;
 #endif
 	mode = snd_virmidi_file_flags(file);
+	if ((file->f_flags & O_APPEND) || minor < 256)
+		mode |= SND_RAWMIDI_LFLG_APPEND;
 
 	if ((mode & SND_RAWMIDI_LFLG_INPUT) &&
 	    !(rdev->dev_flags & SND_RAWMIDI_INFO_INPUT))
@@ -221,11 +232,17 @@ static int snd_virmidi_open(unsigned short minor, int cardnum, int device,
 	if (mode & SND_RAWMIDI_LFLG_OUTPUT &&
 	    !(rdev->dev_flags & SND_RAWMIDI_INFO_OUTPUT))
 		return -ENXIO;
+	if (mode & SND_RAWMIDI_LFLG_OUTPUT) {
+		if (rdev->write_files > 0 && !(mode & SND_RAWMIDI_LFLG_APPEND))
+			return -EINVAL;
+	}
 
 	rmidi = snd_magic_kcalloc(snd_virmidi_t, 0, GFP_KERNEL);
 	if (rmidi == NULL)
 		return -ENOMEM;
-	if (snd_midi_event_new(&rmidi->parser) < 0) {
+
+	obufsize = (mode & SND_RAWMIDI_LFLG_OUTPUT) ? MAX_MIDI_EVENT_BUF : 0;
+	if (snd_midi_event_new(obufsize, &rmidi->parser) < 0) {
 		snd_magic_kfree(rmidi);
 		return -ENOMEM;
 	}
@@ -243,11 +260,11 @@ static int snd_virmidi_open(unsigned short minor, int cardnum, int device,
 	init_waitqueue_head(&ochn->sleep);
 
 	if (mode & SND_RAWMIDI_LFLG_INPUT) {
-		if (snd_virmidi_init_buffer(rmidi, SND_RAWMIDI_CHANNEL_INPUT) < 0)
+		if (snd_virmidi_init_buffer(rmidi, SND_RAWMIDI_CHANNEL_INPUT, PAGE_SIZE, 1) < 0)
 			goto _err;
 	}
 	if (mode & SND_RAWMIDI_LFLG_OUTPUT) {
-		if (snd_virmidi_init_buffer(rmidi, SND_RAWMIDI_CHANNEL_OUTPUT) < 0)
+		if (snd_virmidi_init_buffer(rmidi, SND_RAWMIDI_CHANNEL_OUTPUT, obufsize, 0) < 0)
 			goto _err;
 	}
 
@@ -261,6 +278,10 @@ static int snd_virmidi_open(unsigned short minor, int cardnum, int device,
 	rmidi->next = rdev->filelist;
 	rdev->filelist = rmidi;
 	rdev->files++;
+	if (mode & SND_RAWMIDI_LFLG_INPUT)
+		rdev->read_files++;
+	if (mode & SND_RAWMIDI_LFLG_OUTPUT)
+		rdev->write_files++;
 	write_unlock_irqrestore(&rdev->list_lock, flags);
 
 	up(&rdev->open_mutex);
@@ -305,13 +326,17 @@ static int snd_virmidi_release(unsigned short minor, int cardnum, int device,
 			else
 				rdev->filelist = rmidi->next;
 			rdev->files--;
+			if (rmidi->flags & SND_RAWMIDI_LFLG_INPUT)
+				rdev->read_files--;
+			if (rmidi->flags & SND_RAWMIDI_LFLG_OUTPUT)
+				rdev->write_files--;
 			break;
 		}
 	}
 	write_unlock_irqrestore(&rdev->list_lock, flags);
 
 	/* send reset events if no more opened files */
-	if (rdev->files <= 0 && (rdev->seq_flags & SND_RAWMIDI_INFO_OUTPUT)) {
+	if (rdev->write_files <= 0 && (rdev->seq_flags & SND_RAWMIDI_INFO_OUTPUT)) {
 		snd_seq_event_t ev;
 		int i;
 
@@ -376,12 +401,28 @@ static int snd_virmidi_info(snd_virmidi_t *rmidi, snd_rawmidi_info_t *_info)
 
 /*
  * change output buffer parameters -
- * since we have no actual output buffer, do nothing.
+ * reset the size of buffer
  */
 static int snd_virmidi_output_params(snd_virmidi_t *rmidi,
 				     snd_rawmidi_params_t *params)
 {
+	snd_virmidi_channel_t *pchn;
+
 	snd_virmidi_flush_output(rmidi);
+	if (params->size < 32 || params->size > 1024L * 1024L)
+		return -EINVAL;
+	if (params->room < 1 || params->room >= params->size)
+		return -EINVAL;
+	if (params->max < 1 || params->max >= params->size || params->max < params->room)
+		return -EINVAL;
+	pchn = &rmidi->chn[SND_RAWMIDI_CHANNEL_OUTPUT];
+	if (params->size != pchn->size) {
+		if (snd_midi_event_resize_buffer(rmidi->parser, pchn->size) < 0)
+			return -ENOMEM;
+		pchn->size = params->size;
+	}
+	pchn->used_max = params->max;
+	pchn->used_room = params->room;
 	return 0;
 }
 
@@ -421,8 +462,9 @@ static int snd_virmidi_output_status(snd_virmidi_t *rmidi,
 	unsigned long flags;
 	snd_virmidi_channel_t *pchn;
 
+	snd_debug_check(rmidi->parser == NULL, -EINVAL);
 	pchn = &rmidi->chn[SND_RAWMIDI_CHANNEL_OUTPUT];
-	memset(&status, 0, sizeof(status));
+	memset(status, 0, sizeof(*status));
 	spin_lock_irqsave(&pchn->lock, flags);
 	status->channel = SND_RAWMIDI_CHANNEL_OUTPUT;
 	status->size = pchn->size;
@@ -442,7 +484,7 @@ static int snd_virmidi_input_status(snd_virmidi_t *rmidi,
 	snd_virmidi_channel_t *pchn;
 
 	pchn = &rmidi->chn[SND_RAWMIDI_CHANNEL_INPUT];
-	memset(&status, 0, sizeof(status));
+	memset(status, 0, sizeof(*status));
 	spin_lock_irqsave(&pchn->lock, flags);
 	status->channel = SND_RAWMIDI_CHANNEL_INPUT;
 	status->size = pchn->size;
@@ -839,7 +881,7 @@ static int snd_virmidi_dispatch_event(snd_virmidi_t *rmidi,
 static long snd_virmidi_write(struct file *file, const char *_buf, long count)
 {
 	long result;
-	int err, sent;
+	int err;
 	snd_virmidi_t *rmidi;
 	snd_seq_event_t ev;
 	snd_virmidi_channel_t *pchn;
@@ -848,7 +890,6 @@ static long snd_virmidi_write(struct file *file, const char *_buf, long count)
 
 	rmidi = snd_magic_cast(snd_virmidi_t, file->private_data, -ENXIO);
 	result = 0;
-	sent = 0;
 	err = 0;
 	snd_virmidi_init_event(rmidi->devptr, &ev);
 	pchn = &rmidi->chn[SND_RAWMIDI_CHANNEL_OUTPUT];
@@ -856,11 +897,15 @@ static long snd_virmidi_write(struct file *file, const char *_buf, long count)
 		err = snd_midi_event_encode_byte(rmidi->parser, *buf, &ev);
 		if (err < 0)
 			break;
-		else if (err > 0) {
+		else if (err == 0) {
 			spin_lock_irqsave(&pchn->lock, flags);
-			pchn->bytes += sent;
+			pchn->used++;
+			spin_unlock_irqrestore(&pchn->lock, flags);
+		} else {	/* event packet is ready */
+			spin_lock_irqsave(&pchn->lock, flags);
+			pchn->bytes += pchn->used + 1;
+			pchn->used = 0;
 			spin_unlock_irqrestore(&pchn->lock, flags);
-			sent = 0;
 			err = snd_virmidi_dispatch_event(rmidi, &ev, file);
 			/* release sysex data */
 			if (snd_seq_ev_is_variable(&ev) && ev.data.ext.ptr)
@@ -873,7 +918,6 @@ static long snd_virmidi_write(struct file *file, const char *_buf, long count)
 		result++;
 		buf++;
 		count--;
-		sent++;
 	}
 
 	return result > 0 ? result : err;
@@ -927,7 +971,8 @@ static void snd_virmidi_dev_proc_info_read(snd_info_buffer_t * buffer,
 	snd_iprintf(buffer, "%s\n\n", rdev->name);
 	snd_iprintf(buffer, "Sequencer Port = %d:%d\n", rdev->client, rdev->port);
 	read_lock(&rdev->list_lock);
-	snd_iprintf(buffer, "Files = %d\n", rdev->files);
+	snd_iprintf(buffer, "Files = %d (Read = %d / Write = %d)\n",
+		    rdev->files, rdev->read_files, rdev->write_files);
 	i = 0;
 	for (rmidi = rdev->filelist; rmidi; rmidi = rmidi->next, i++) {
 		snd_iprintf(buffer, "[File %d]\n", i);
@@ -1078,6 +1123,8 @@ int snd_virmidi_new(snd_card_t *card, int device, snd_virmidi_dev_t **rrdev)
 		SND_RAWMIDI_INFO_DUPLEX;
 	rdev->seq_flags = 0;
 	rdev->files = 0;
+	rdev->read_files = 0;
+	rdev->write_files = 0;
 	rdev->filelist = NULL;
 	
 	snd_switch_prepare(card, &rdev->switches[SND_RAWMIDI_CHANNEL_INPUT], rdev, SND_CTL_IFACE_RAWMIDI, device, SND_RAWMIDI_CHANNEL_INPUT);
