@@ -1148,7 +1148,7 @@ static long snd_timer_user_read(struct file *file, char *buffer, long count)
 				break;
 			}
 
-			current->state = TASK_INTERRUPTIBLE;
+			set_current_state(TASK_INTERRUPTIBLE);
 			/* 2.3.x: init_waitqueue_entry(&wait, current); */
 			wait.task = current;
 			add_wait_queue(&tu->qchange_sleep, &wait);
