@@ -108,8 +108,8 @@ static void snd_emu10k1_init_efx(emu10k1_t *emu)
 	snd_emu10k1_write_op(emu, 6, 0x101, 0x101, 0x40, emu->APS ? 0x17 : 0x40, &pc);
 	/* FrontOut (AC97) = GPR[0/1] */
 	snd_emu10k1_write_op(emu, 6, 0x20, 0x40, 0x40, 0x100, &pc);
-	snd_emu10k1_write_op(emu, 6, 0x21, 0x40, 0x41, 0x101, &pc);
-	/* RearOut = (GPR[0/1] * RearVolume) >> 31 */
+	snd_emu10k1_write_op(emu, 6, 0x21, 0x40, 0x40, 0x101, &pc);
+	/* RearOut = (GPR[0/1] * RearVolume GPR[10/11]) >> 31 */
 	/*   RearVolume = GRP[0x10/0x11] */
 	snd_emu10k1_write_op(emu, 0, 0x28, 0x40, 0x110, 0x100, &pc);
 	snd_emu10k1_write_op(emu, 0, 0x29, 0x40, 0x111, 0x101, &pc);
@@ -119,9 +119,9 @@ static void snd_emu10k1_init_efx(emu10k1_t *emu)
 	/* Mute Out2 */
 	snd_emu10k1_write_op(emu, 6, 0x24, 0x40, 0x40, 0x40, &pc);
 	snd_emu10k1_write_op(emu, 6, 0x25, 0x40, 0x40, 0x40, &pc);
-	/* Mute Out3 */
-	snd_emu10k1_write_op(emu, 6, 0x26, 0x40, 0x40, 0x40, &pc);
-	snd_emu10k1_write_op(emu, 6, 0x27, 0x40, 0x40, 0x40, &pc);
+	/* Enable LD2 Microphones */
+	snd_emu10k1_write_op(emu, 6, 0x26, 0x40, 0x40, 0x100, &pc);
+	snd_emu10k1_write_op(emu, 6, 0x27, 0x40, 0x40, 0x101, &pc);
 	/* Input0 (AC97) -> Record */
 	snd_emu10k1_write_op(emu, 6, 0x2a, 0x40, 0x40, 0x10, &pc);
 	snd_emu10k1_write_op(emu, 6, 0x2b, 0x40, 0x40, 0x11, &pc);
@@ -546,22 +546,18 @@ int snd_emu10k1_create(snd_card_t * card,
 	if (emu == NULL)
 		return -ENOMEM;
 	emu->card = card;
-	emu->reg_lock = SPIN_LOCK_UNLOCKED;
-	emu->emu_lock = SPIN_LOCK_UNLOCKED;
-	emu->voice_lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&emu->reg_lock);
+	spin_lock_init(&emu->emu_lock);
+	spin_lock_init(&emu->voice_lock);
+	spin_lock_init(&emu->synth_lock);
 	init_MUTEX(&emu->ptb_lock);
 	emu->pci = pci;
 	emu->dma1ptr = dma1ptr;
 	emu->dma2ptr = dma2ptr;
 	emu->irqptr = irqptr;
-	emu->synth_lock = SPIN_LOCK_UNLOCKED;
 	emu->synth = NULL;
 	emu->get_synth_voice = NULL;
-#ifdef NEW_PCI
-	emu->port = pci->resource[0].start;
-#else
-	emu->port = pci->base_address[0] & ~PCI_BASE_ADDRESS_SPACE;
-#endif
+	emu->port = pci_resource_start(pci, 0);
 
 	emu->ptb_pages = snd_malloc_pages(32 * 1024, NULL, 0);
 	if (emu->ptb_pages == NULL || ((long)virt_to_phys(emu->ptb_pages) & ~0x7fffffffUL)) {
@@ -651,18 +647,17 @@ int snd_emu10k1_mixer(emu10k1_t * emu, int device, snd_pcm_t * pcm, snd_kmixer_t
  *  INIT part
  */
 
-#ifdef MODULE
-
-int __init init_module(void)
+static int __init alsa_emu10k1_init(void)
 {
 	return 0;
 }
 
-void __exit cleanup_module(void)
+static void __exit alsa_emu10k1_exit(void)
 {
 }
 
-#endif
+module_init(alsa_emu10k1_init)
+module_exit(alsa_emu10k1_exit)
 
 EXPORT_SYMBOL(snd_emu10k1_create);
 EXPORT_SYMBOL(snd_emu10k1_mixer);
