@@ -44,8 +44,9 @@ static struct {
 	{	0x414c4700,	"Avance Logic"			},
 	{	0x43525900,	"Cirrus Logic"			},
 	{	0x4e534300,	"National Semiconductor"	},
+	{	0x53494c00,	"Silicon Laboratory"		},
 	{	0x54524100,	"TriTech"			},
-	{	0x575d4c00,	"Wolfson"			},
+	{	0x574d4c00,	"Wolfson"			},
 	{	0x83847600,	"SigmaTel"			},
 	{	0,		NULL				}
 };
@@ -54,18 +55,24 @@ static struct {
 	unsigned int id;
 	char *name;
 } snd_ac97_codec_ids[] = {
-	{	0x414B4D00,	"AK4540"			},
+	{	0x414b4d00,	"AK4540"			},
+	{	0x414b4d02,	"AK4543",			},
 	{	0x41445303,	"AD1819"			},
 	{	0x41445340,	"AD1881"			},
 	{	0x414c4710,	"ALC200/200P"			},
 	{	0x43525903,	"CS4297"			},
 	{	0x43525913,	"CS4297A"			},
 	{	0x42525923,	"CS4294"			},
-	{	0x43525931,	"CS4299"			},
-	{	0x43525933,	"CS4299+"			}, // some new revision?
+	{	0x43525931,	"CS4299 rev A"			},
+	{	0x43525933,	"CS4299 rev C"			},
+	{	0x43525934,	"CS4299 rev D"			},
 	{	0x4e534331,	"LM4549"			},
+	{	0x53494c22,	"Si3036"			},
+	{	0x53494c23,	"Si3038"			},
 	{	0x54524108,	"TR28028"			}, // added by xin jin [07/09/99]
-	{	0x574D4C00,	"WM9704"			}, // added by xin jin [07/09/99]
+	{	0x574d4c00,	"WM9701A"			},
+	{	0x574d4c03,	"WM9703/9704",			},
+	{	0x574d4c04,	"WM9704 (quad)",		},
 	{	0x83847604,	"STAC9701/3/4/5"		},
 	{	0x83847605,	"STAC9704"			},
 	{	0x83847608,	"STAC9708/11"			},
@@ -122,7 +129,6 @@ static int snd_ac97_valid_reg(ac97_t *ac97, unsigned short reg)
 		return 0;
 	case 0x41445303:	/* AD1819 */
 	case 0x41445340:	/* AD1881 */
-	case 0x41445348:	/* AD1885? */
 		if (reg >= 0x3a && reg <= 0x59)
 			return 0;
 		return 1;
@@ -1964,7 +1970,7 @@ int snd_ac97_mixer(snd_card_t * card, int device,
 			strcat(mixer->name, snd_ac97_codec_ids[idx].name);
 			goto __skip;
 		}
-	sprintf(mixer->name + strlen(mixer->name), " (%x)\n", ac97->id & 0xff);
+	sprintf(mixer->name + strlen(mixer->name), " (%x)", ac97->id & 0xff);
       __skip:
 	snd_ac97_chip_init(ac97);
 	snd_ac97_proc_init(card, ac97);
