@@ -1109,7 +1109,7 @@ int snd_ak4531_mixer(snd_card_t * card, int device,
 	if (ak4531 == NULL)
 		return -ENOMEM;
 	memcpy(ak4531, _ak4531, sizeof(*_ak4531));
-	ak4531->reg_lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&ak4531->reg_lock);
 	if ((err = snd_mixer_new(card, "AK4531", device, &mixer)) < 0)
 		return err;
 	strcpy(mixer->name, "Asahi Kasei AK4531");
@@ -1537,15 +1537,14 @@ EXPORT_SYMBOL(snd_ak4531_mixer);
  *  INIT part
  */
 
-#ifdef MODULE
-
-int __init init_module(void)
+static int __init alsa_ak4531_init(void)
 {
 	return 0;
 }
 
-void __exit cleanup_module(void)
+static void __exit alsa_ak4531_exit(void)
 {
 }
 
-#endif
+module_init(alsa_ak4531_init)
+module_exit(alsa_ak4531_exit)
