@@ -37,8 +37,9 @@
 
 static int get_zone(snd_emux_t *emu, snd_emux_port_t *port, int *notep, int vel, snd_midi_channel_t *chan, snd_sf_zone_t **table);
 static int get_bank(snd_emux_port_t *port, snd_midi_channel_t *chan);
+static void terminate_note1(snd_emux_t *emu, int note, snd_midi_channel_t *chan, int free);
 static void exclusive_note_off(snd_emux_t *emu, snd_emux_port_t *port, int exclass);
-static void terminate_voice(snd_emux_t *emu, snd_emux_voice_t *vp);
+static void terminate_voice(snd_emux_t *emu, snd_emux_voice_t *vp, int free);
 static void update_voice(snd_emux_t *emu, snd_emux_voice_t *vp, int update);
 static void setup_voice(snd_emux_voice_t *vp);
 static int calc_pan(snd_emux_voice_t *vp);
@@ -80,7 +81,7 @@ snd_emux_note_on(void *p, int note, int vel, snd_midi_channel_t *chan)
 	}
 
 	/* Turn off the same note on the same channel. */
-	snd_emux_terminate_note(port, note, chan);
+	terminate_note1(emu, key, chan, 0);
 
 	spin_lock_irqsave(&emu->voice_lock, flags);
 	for (i = 0; i < nvoices; i++) {
@@ -310,6 +311,27 @@ snd_emux_release_voice(snd_emux_t *emu)
 }
 
 
+/*
+ * terminate note - if free flag is true, free the terminated voice
+ */
+static void
+terminate_note1(snd_emux_t *emu, int note, snd_midi_channel_t *chan, int free)
+{
+	int  i;
+	snd_emux_voice_t *vp;
+	unsigned long flags;
+
+	spin_lock_irqsave(&emu->voice_lock, flags);
+	for (i = 0; i < emu->max_voices; i++) {
+		vp = &emu->voices[i];
+		if (STATE_IS_PLAYING(vp->state) && vp->chan == chan &&
+		    vp->key == note)
+			terminate_voice(emu, vp, free);
+	}
+	spin_unlock_irqrestore(&emu->voice_lock, flags);
+}
+
+
 /*
  * terminate note - exported for midi emulation
  */
@@ -317,9 +339,6 @@ void
 snd_emux_terminate_note(void *p, int note, snd_midi_channel_t *chan)
 {
 	snd_emux_t *emu;
-	snd_emux_voice_t *vp;
-	int  i;
-	unsigned long flags;
 	snd_emux_port_t *port;
 
 	port = snd_magic_cast(snd_emux_port_t, p,);
@@ -329,15 +348,7 @@ snd_emux_terminate_note(void *p, int note, snd_midi_channel_t *chan)
 	snd_debug_check(emu == NULL,);
 	snd_debug_check(emu->ops.terminate == NULL,);
 
-	spin_lock_irqsave(&emu->voice_lock, flags);
-	for (i = 0; i < emu->max_voices; i++) {
-		vp = &emu->voices[i];
-		if (STATE_IS_PLAYING(vp->state) && vp->chan == chan &&
-		    vp->key == note) {
-			terminate_voice(emu, vp);
-		}
-	}
-	spin_unlock_irqrestore(&emu->voice_lock, flags);
+	terminate_note1(emu, note, chan, 1);
 }
 
 
@@ -355,9 +366,13 @@ snd_emux_terminate_all(snd_emux_t *emu)
 	for (i = 0; i < emu->max_voices; i++) {
 		vp = &emu->voices[i];
 		if (STATE_IS_PLAYING(vp->state))
-			terminate_voice(emu, vp);
-		if (emu->ops.reset)
-			emu->ops.reset(emu, i);
+			terminate_voice(emu, vp, 0);
+		if (vp->state == SND_EMUX_ST_OFF) {
+			if (emu->ops.free_voice)
+				emu->ops.free_voice(vp);
+			if (emu->ops.reset)
+				emu->ops.reset(emu, i);
+		}
 		vp->time = 0;
 	}
 	/* initialize allocation time */
@@ -386,8 +401,13 @@ snd_emux_sounds_off_all(snd_emux_port_t *port)
 	for (i = 0; i < emu->max_voices; i++) {
 		vp = &emu->voices[i];
 		if (STATE_IS_PLAYING(vp->state) &&
-		    vp->port == port) {
-			terminate_voice(emu, vp);
+		    vp->port == port)
+			terminate_voice(emu, vp, 0);
+		if (vp->state == SND_EMUX_ST_OFF) {
+			if (emu->ops.free_voice)
+				emu->ops.free_voice(vp);
+			if (emu->ops.reset)
+				emu->ops.reset(emu, i);
 		}
 	}
 	spin_unlock_irqrestore(&emu->voice_lock, flags);
@@ -410,7 +430,7 @@ exclusive_note_off(snd_emux_t *emu, snd_emux_port_t *port, int exclass)
 		vp = &emu->voices[i];
 		if (STATE_IS_PLAYING(vp->state) && vp->port == port &&
 		    vp->reg.exclusiveClass == exclass) {
-			terminate_voice(emu, vp);
+			terminate_voice(emu, vp, 0);
 		}
 	}
 	spin_unlock_irqrestore(&emu->voice_lock, flags);
@@ -418,16 +438,17 @@ exclusive_note_off(snd_emux_t *emu, snd_emux_port_t *port, int exclass)
 
 /*
  * terminate a voice
+ * if free flag is true, call free_voice after termination
  */
 static void
-terminate_voice(snd_emux_t *emu, snd_emux_voice_t *vp)
+terminate_voice(snd_emux_t *emu, snd_emux_voice_t *vp, int free)
 {
 	emu->ops.terminate(vp);
 	vp->time = emu->use_time++;
 	vp->chan = NULL;
 	vp->port = NULL;
 	vp->state = SND_EMUX_ST_OFF;
-	if (emu->ops.free_voice)
+	if (free && emu->ops.free_voice)
 		emu->ops.free_voice(vp);
 }
 
