@@ -361,7 +361,7 @@ static void snd_gf1_pcm_separate_8bit(unsigned char *buf, int dma_size, int coun
 static int snd_gf1_pcm_playback_memcpy(snd_pcm_subchn_t *subchn,
 				       int voice,
 				       int pos,
-				       const void *src,
+				       void *src,
 				       int count)
 {
 	snd_pcm_runtime_t *runtime = subchn->runtime;
@@ -658,7 +658,7 @@ static int snd_gf1_pcm_playback_open(void *private_data,
 	if (pcmp == NULL)
 		return -ENOMEM;
 	pcmp->gus = gus;
-	pcmp->lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&pcmp->lock);
 	init_waitqueue_head(&pcmp->sleep);
 	atomic_set(&pcmp->dma_count, 0);
 
