@@ -151,6 +151,12 @@ static void snd_ad1816a_open(ad1816a_t *codec, unsigned int mode)
 			AD1816A_CAPTURE_IRQ_PENDING, 0x00);
 		snd_ad1816a_write_mask(codec, AD1816A_INTERRUPT_ENABLE,
 			AD1816A_CAPTURE_IRQ_ENABLE, 0xffff);
+		break;
+	case AD1816A_MODE_TIMER:
+		snd_ad1816a_out_mask(codec, AD1816A_INTERRUPT_STATUS,
+			AD1816A_TIMER_IRQ_PENDING, 0x00);
+		snd_ad1816a_write_mask(codec, AD1816A_INTERRUPT_ENABLE,
+			AD1816A_TIMER_IRQ_ENABLE, 0xffff);
 	}
 	codec->mode |= mode;
 
@@ -175,6 +181,12 @@ static void snd_ad1816a_close(ad1816a_t *codec, unsigned int mode)
 			AD1816A_CAPTURE_IRQ_PENDING, 0x00);
 		snd_ad1816a_write_mask(codec, AD1816A_INTERRUPT_ENABLE,
 			AD1816A_CAPTURE_IRQ_ENABLE, 0x0000);
+		break;
+	case AD1816A_MODE_TIMER:
+		snd_ad1816a_out_mask(codec, AD1816A_INTERRUPT_STATUS,
+			AD1816A_TIMER_IRQ_PENDING, 0x00);
+		snd_ad1816a_write_mask(codec, AD1816A_INTERRUPT_ENABLE,
+			AD1816A_TIMER_IRQ_ENABLE, 0x0000);
 	}
 	if (!((codec->mode &= ~mode) & AD1816A_MODE_OPEN))
 		codec->mode = 0;
@@ -371,6 +383,9 @@ void snd_ad1816a_interrupt(snd_pcm_t *pcm, unsigned char status)
 	if (status & AD1816A_CAPTURE_IRQ_PENDING)
 		snd_pcm_transfer_done(codec->capture_subchn);
 
+	if (status & AD1816A_TIMER_IRQ_PENDING)
+		snd_timer_interrupt(codec->timer, codec->timer->sticks);
+
 	snd_ad1816a_out(codec, AD1816A_INTERRUPT_STATUS, 0x00);
 	spin_unlock_irqrestore(&codec->lock, flags);
 }
@@ -424,6 +439,79 @@ static snd_pcm_hardware_t snd_ad1816a_capture = {
 	snd_ad1816a_capture_pointer,
 };
 
+
+static int snd_ad1816a_timer_close(snd_timer_t *timer)
+{
+	ad1816a_t *codec;
+
+	codec = snd_magic_cast(ad1816a_t, timer->private_data, -ENXIO);
+	snd_ad1816a_close(codec, AD1816A_MODE_TIMER);
+	return 0;
+}
+
+static int snd_ad1816a_timer_open(snd_timer_t *timer)
+{
+	ad1816a_t *codec;
+
+	codec = snd_magic_cast(ad1816a_t, timer->private_data, -ENXIO);
+	snd_ad1816a_open(codec, AD1816A_MODE_TIMER);
+	return 0;
+}
+
+static unsigned long snd_ad1816a_timer_resolution(snd_timer_t *timer)
+{
+	snd_debug_check(timer == NULL, 0);
+
+	return 10000;
+}
+
+static void snd_ad1816a_timer_start(snd_timer_t *timer)
+{
+	unsigned short bits;
+	unsigned long flags;
+	ad1816a_t *codec;
+
+	codec = snd_magic_cast(ad1816a_t, timer->private_data, );
+
+	spin_lock_irqsave(&codec->lock, flags);
+	bits = snd_ad1816a_read(codec, AD1816A_INTERRUPT_ENABLE);
+
+	if (!(bits & AD1816A_TIMER_ENABLE)) {
+		snd_ad1816a_write(codec, AD1816A_TIMER_BASE_COUNT,
+			timer->sticks & 0xffff);
+
+		snd_ad1816a_write_mask(codec, AD1816A_INTERRUPT_ENABLE,
+			AD1816A_TIMER_ENABLE, 0xffff);
+	}
+	spin_unlock_irqrestore(&codec->lock, flags);
+}
+
+static void snd_ad1816a_timer_stop(snd_timer_t *timer)
+{
+	unsigned long flags;
+	ad1816a_t *codec;
+
+	codec = snd_magic_cast(ad1816a_t, timer->private_data, );
+	spin_lock_irqsave(&codec->lock, flags);
+
+	snd_ad1816a_write_mask(codec, AD1816A_INTERRUPT_ENABLE,
+		AD1816A_TIMER_ENABLE, 0x0000);
+
+	spin_unlock_irqrestore(&codec->lock, flags);
+}
+
+static struct snd_stru_timer_hardware snd_ad1816a_timer = {
+	SND_TIMER_HW_AUTO,		/* flags */
+	10000,				/* resolution (us * 1000) */
+	65535,				/* high timer mark */
+	snd_ad1816a_timer_open,		/* open */
+	snd_ad1816a_timer_close,	/* close */
+	snd_ad1816a_timer_resolution,	/* resolution */
+	snd_ad1816a_timer_start,	/* start */
+	snd_ad1816a_timer_stop,		/* stop */
+};
+
+
 static int snd_ad1816a_playback_open(void *private_data,
 				     snd_pcm_subchn_t *subchn)
 {
@@ -531,17 +619,21 @@ static void snd_ad1816a_free(void *private_data)
 {
 	ad1816a_t *codec = snd_magic_cast(ad1816a_t, private_data, );
 
+	if (codec->timer)
+		snd_device_free(codec->card, codec->timer);
+
 	snd_magic_kfree(codec);
 }
 
 int snd_ad1816a_new_pcm(snd_card_t *card, int device,
 			unsigned short port, snd_irq_t *irqptr,
 			snd_dma_t *dma1ptr, snd_dma_t *dma2ptr,
-			snd_pcm_t **rpcm)
+			int timer_dev, snd_pcm_t **rpcm)
 {
 	int error;
 	ad1816a_t *codec;
 	snd_pcm_t *pcm;
+	snd_timer_t *timer;
 
 	*rpcm = NULL;
 	if ((error = snd_pcm_new(card, "AD1816A", device, 1, 1, &pcm)))
@@ -581,9 +673,19 @@ int snd_ad1816a_new_pcm(snd_card_t *card, int device,
 	}
 
 	strcpy(pcm->name, "AD1816A");
-
 	snd_ad1816a_init(codec);
 
+	if ((error = snd_timer_new(card, "AD1816A", timer_dev, &timer)) < 0) {
+		snd_device_free(card, pcm);
+
+		return error;
+	}
+	strcpy(timer->name, pcm->name);
+
+	timer->private_data = codec;
+	codec->timer = timer;
+	memcpy(&timer->hw, &snd_ad1816a_timer, sizeof(snd_ad1816a_timer));
+
 	*rpcm = pcm;
 	return 0;
 }
@@ -634,10 +736,9 @@ static snd_kmixer_element_t *snd_ad1816a_get_src_element(ad1816a_t *codec,
 static int snd_ad1816a_mixer_mux(snd_kmixer_element_t *element, int writing,
 						snd_kmixer_element_t **elements)
 {
-	unsigned short bits;
+	int bits, left, right, nleft, nright;
 	ad1816a_t *codec = (ad1816a_t *) element->private_data;
 	unsigned long flags;
-	int left, right, nleft, nright;
 	int changed = 0;
 
 	spin_lock_irqsave(&codec->lock, flags);
@@ -1800,3 +1901,4 @@ static void __exit alsa_ad1816a_exit(void)
 
 module_init(alsa_ad1816a_init)
 module_exit(alsa_ad1816a_exit)
+
