@@ -245,7 +245,7 @@ static void snd_ad1848_mce_down(ad1848_t * codec)
 			snd_printk("ad1848_mce_down - auto calibration time out (2)\n");
 			return;
 		}
-		current->state = TASK_INTERRUPTIBLE;
+		set_current_state(TASK_INTERRUPTIBLE);
 		time = schedule_timeout(time);
 		spin_lock_irqsave(&codec->reg_lock, flags);
 	}
@@ -259,7 +259,7 @@ static void snd_ad1848_mce_down(ad1848_t * codec)
 			snd_printk("ad1848_mce_down - auto calibration time out (3)\n");
 			return;
 		}
-		current->state = TASK_INTERRUPTIBLE;
+		set_current_state(TASK_INTERRUPTIBLE);
 		time = schedule_timeout(time);
 		spin_lock_irqsave(&codec->reg_lock, flags);
 	}
