@@ -328,7 +328,7 @@ void snd_cs4231_mce_down(cs4231_t * codec)
 			snd_printk("cs4231_mce_down - auto calibration time out (2)\n");
 			return;
 		}
-		current->state = TASK_INTERRUPTIBLE;
+		set_current_state(TASK_INTERRUPTIBLE);
 		time = schedule_timeout(time);
 		spin_lock_irqsave(&codec->reg_lock, flags);
 	}
@@ -342,7 +342,7 @@ void snd_cs4231_mce_down(cs4231_t * codec)
 			snd_printk("cs4231_mce_down - auto calibration time out (3)\n");
 			return;
 		}
-		current->state = TASK_INTERRUPTIBLE;		
+		set_current_state(TASK_INTERRUPTIBLE);		
 		time = schedule_timeout(time);
 		spin_lock_irqsave(&codec->reg_lock, flags);
 	}
