@@ -875,7 +875,7 @@ static int snd_cs4236_iec958_set(snd_kmixer_t * mixer, snd_kswitch_t * kswitch,
 
 		time = HZ / 5;
 		while (time > 0) {
-			current->state = TASK_INTERRUPTIBLE;
+			set_current_state(TASK_INTERRUPTIBLE);
 			time = schedule_timeout(time);
 		}
 
@@ -889,7 +889,7 @@ static int snd_cs4236_iec958_set(snd_kmixer_t * mixer, snd_kswitch_t * kswitch,
 
 		time = HZ / 5;
 		while (time > 0) {
-			current->state = TASK_INTERRUPTIBLE;
+			set_current_state(TASK_INTERRUPTIBLE);
 			time = schedule_timeout(time);
 		}
 
