@@ -280,7 +280,7 @@ static int
 wavefront_sleep (int limit)
 
 {
-	current->state = TASK_INTERRUPTIBLE;
+	set_current_state(TASK_INTERRUPTIBLE);
 	schedule_timeout(limit);
 
 	return signal_pending(current);
