@@ -1434,7 +1434,8 @@ int snd_cs461x_create(snd_card_t * card,
 	unsigned short cmdw;
 	unsigned char cmdb;
 	unsigned int tmp;
-	int idx, err;
+	int err;
+	signed long end_time;
 	static snd_device_ops_t ops = {
 		(snd_dev_free_t *)snd_cs461x_free,
 		NULL,
@@ -1476,7 +1477,6 @@ int snd_cs461x_create(snd_card_t * card,
 		cmdw |= PCI_COMMAND_MEMORY;
 		pci_write_config_word(pci, PCI_COMMAND, cmdw);
 	}
-	pci_set_master(pci);
 	pci_read_config_byte(pci, PCI_LATENCY_TIMER, &cmdb);
 	if (cmdb < 32)
 		cmdb = 32;
@@ -1573,26 +1573,24 @@ int snd_cs461x_create(snd_card_t * card,
 	/*
 	 * Wait for the codec ready signal from the AC97 codec.
 	 */
-	for (idx = 0; idx < 1000; idx++) {
-		/*
-		 *  First, lets wait a short while to let things settle out a bit,
-		 *  and to prevent retrying the read too quickly.
-		 */
-		udelay(50);
-
+	end_time = jiffies + 3 * (HZ >> 2);
+	do {
 		/*
 		 *  Read the AC97 status register to see if we've seen a CODEC READY
 		 *  signal from the AC97 codec.
 		 */
 		if (snd_cs461x_peekBA0(codec, BA0_ACSTS) & ACSTS_CRDY)
 			break;
-	}
+		set_current_state(TASK_UNINTERRUPTIBLE);
+		schedule_timeout(1);
+	} while (end_time - (signed long)jiffies >= 0);
 
 	/*
 	 *  Make sure CODEC is READY.
 	 */
 	if (!(snd_cs461x_peekBA0(codec, BA0_ACSTS) & ACSTS_CRDY)) {
 		snd_printk("cs461x: create - never read codec ready from AC'97\n");
+		snd_printk("cs461x: it is not probably bug, try to use CS4236 driver\n");
 		snd_cs461x_free(codec);
 		return -EIO;
 	}
@@ -1607,19 +1605,17 @@ int snd_cs461x_create(snd_card_t * card,
 	 *  Wait until we've sampled input slots 3 and 4 as valid, meaning that
 	 *  the codec is pumping ADC data across the AC-link.
 	 */
-	for (idx = 0; idx < 2000; idx++) {
-		/*
-		 *  First, lets wait a short while to let things settle out a bit,
-		 *  and to prevent retrying the read too quickly.
-		 */
-		udelay(500);
+	end_time = jiffies + 3 * (HZ >> 2);
+	do {
 		/*
 		 *  Read the input slot valid register and see if input slots 3 and
 		 *  4 are valid yet.
 		 */
 		if ((snd_cs461x_peekBA0(codec, BA0_ACISV) & (ACISV_ISV3 | ACISV_ISV4)) == (ACISV_ISV3 | ACISV_ISV4))
 			break;
-	}
+		set_current_state(TASK_UNINTERRUPTIBLE);
+		schedule_timeout(1);
+	} while (end_time - (signed long)jiffies >= 0);
 
 	/*
 	 *  Make sure input slots 3 and 4 are valid.  If not, then return
