@@ -1504,7 +1504,21 @@ static void snd_ensoniq_midi_interrupt(ensoniq_t * ensoniq,
 	unsigned long flags;
 	unsigned char status, mask, byte;
 
-	/* do Tx at first */
+	/* do Rx at first */
+	spin_lock_irqsave(&ensoniq->reg_lock, flags);
+	mask = ensoniq->uartm & ES_MODE_INPUT ? ES_RXRDY : 0;
+	while (mask) {
+		status = inb(ES_REG(ensoniq, UART_STATUS));
+		if ((status & mask) == 0)
+			break;
+		byte = inb(ES_REG(ensoniq, UART_DATA));
+		spin_unlock_irqrestore(&ensoniq->reg_lock, flags);
+		snd_rawmidi_receive(rmidi, &byte, 1);
+		spin_lock_irqsave(&ensoniq->reg_lock, flags);
+	}
+	spin_unlock_irqrestore(&ensoniq->reg_lock, flags);
+
+	/* do Tx at second */
 	spin_lock_irqsave(&ensoniq->reg_lock, flags);
 	mask = ensoniq->uartm & ES_MODE_OUTPUT ? ES_TXRDY : 0;
 	while (mask) {
@@ -1520,22 +1534,6 @@ static void snd_ensoniq_midi_interrupt(ensoniq_t * ensoniq,
 		}
 	}
 	spin_unlock_irqrestore(&ensoniq->reg_lock, flags);
-
-	/* do Rx at second */
-	spin_lock_irqsave(&ensoniq->reg_lock, flags);
-	mask = ensoniq->uartm & ES_MODE_INPUT ? ES_RXRDY : 0;
-	while (mask) {
-		status = inb(ES_REG(ensoniq, UART_STATUS));
-		if ((status & mask) == 0)
-			break;
-		byte = inb(ES_REG(ensoniq, UART_DATA));
-		if (mask & ES_RXRDY) {
-			spin_unlock_irqrestore(&ensoniq->reg_lock, flags);
-			snd_rawmidi_receive(rmidi, &byte, 1);
-			spin_lock_irqsave(&ensoniq->reg_lock, flags);
-		}
-	}
-	spin_unlock_irqrestore(&ensoniq->reg_lock, flags);
 }
 
 static int snd_ensoniq_midi_input_open(snd_rawmidi_t * rmidi)
@@ -1718,6 +1716,10 @@ void snd_ensoniq_interrupt(ensoniq_t * ensoniq)
 	outl(ensoniq->sctrl, ES_REG(ensoniq, SERIAL));
 	spin_unlock_irqrestore(&ensoniq->reg_lock, flags);
 
+	if (ensoniq->rmidi) {
+		if (status & ES_UART)
+			snd_ensoniq_midi_interrupt(ensoniq, ensoniq->rmidi);
+	}
 	if (ensoniq->pcm) {
 		if (status & ES_DAC2)
 			snd_pcm_transfer_done(ensoniq->playback2_subchn);
@@ -1728,10 +1730,6 @@ void snd_ensoniq_interrupt(ensoniq_t * ensoniq)
 		if (status & ES_DAC1)
 			snd_pcm_transfer_done(ensoniq->playback_subchn);
 	}
-	if (ensoniq->rmidi) {
-		if (status & ES_UART)
-			snd_ensoniq_midi_interrupt(ensoniq, ensoniq->rmidi);
-	}
 }
 
 #ifdef CHIP1370
