@@ -1527,26 +1527,18 @@ int snd_solo_create(snd_card_t * card,
 	solo = snd_magic_kcalloc(es1938_t, 0, GFP_KERNEL);
 	if (solo == NULL)
 		return -ENOMEM;
-	solo->reg_lock = SPIN_LOCK_UNLOCKED;
-	solo->mixer_lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&solo->reg_lock);
+	spin_lock_init(&solo->mixer_lock);
 	solo->card = card;
 	solo->pci = pci;
 	solo->irqptr = irqptr;
 	solo->dma1ptr = dma1ptr;
 	solo->dma2ptr = dma2ptr;
-#ifdef NEW_PCI
-	solo->io_port = pci->resource[0].start;
-	solo->sb_port = pci->resource[1].start;
-	solo->vc_port = pci->resource[2].start;
-	solo->mpu_port = pci->resource[3].start;
-	solo->game_port = pci->resource[4].start;
-#else
-	solo->io_port = pci->base_address[0] & ~PCI_BASE_ADDRESS_SPACE;
-	solo->sb_port = pci->base_address[1] & ~PCI_BASE_ADDRESS_SPACE;
-	solo->vc_port = pci->base_address[2] & ~PCI_BASE_ADDRESS_SPACE;
-	solo->mpu_port = pci->base_address[3] & ~PCI_BASE_ADDRESS_SPACE;
-	solo->game_port = pci->base_address[4] & ~PCI_BASE_ADDRESS_SPACE;
-#endif
+	solo->io_port = pci_resource_start(pci, 0);
+	solo->sb_port = pci_resource_start(pci, 1);
+	solo->vc_port = pci_resource_start(pci, 2);
+	solo->mpu_port = pci_resource_start(pci, 3);
+	solo->game_port = pci_resource_start(pci, 4);
 #ifdef SOLO_DDEBUG
 	snd_printk("snd_solo_create: io: 0x%x, sb: 0x%x, vc: 0x%x, mpu: 0x%x, game: 0x%x\n",
 		   solo->io_port, solo->sb_port, solo->vc_port, solo->mpu_port, solo->game_port);
@@ -1664,15 +1656,14 @@ EXPORT_SYMBOL(snd_solo_midi);
  *  INIT part
  */
 
-#ifdef MODULE
-
-int __init init_module(void)
+static int __init alsa_es1938_init(void)
 {
 	return 0;
 }
 
-void __exit cleanup_module(void)
+static void __exit alsa_es1938_exit(void)
 {
 }
 
-#endif
+module_init(alsa_es1938_init)
+module_exit(alsa_es1938_exit)
