@@ -1683,7 +1683,6 @@ static int snd_es1968_playback_open(void *private_data,
 	es->apu[1] = apu1 + 1;
 	es->apu_mode[0] = 0;
 	es->apu_mode[1] = 0;
-	es->reg_lock = SPIN_LOCK_UNLOCKED;
 	es->enable = 0;
 
 	runtime->private_data = es;
@@ -1795,7 +1794,6 @@ static int snd_es1968_capture_open(void *private_data,
 	es->apu_mode[2] = 0;
 	es->apu_mode[3] = 0;
 	es->mixbuf = mixbuf;
-	es->reg_lock = SPIN_LOCK_UNLOCKED;
 	es->enable = 0;
 
 	runtime->private_data = es;
@@ -2114,7 +2112,7 @@ int snd_es1968_create(snd_card_t * card,
 	/* Set Vars */
 
 	esm->type = card->type;
-	esm->reg_lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&esm->reg_lock);
 	esm->card = card;
 	esm->pci = pci;
 	esm->irqptr = irqptr;
@@ -2124,11 +2122,7 @@ int snd_es1968_create(snd_card_t * card,
 	esm->pcmp = pcmp;
 	esm->pcmc = pcmc;
 
-#ifdef NEW_PCI
-	esm->io_port = pci->resource[0].start;
-#else
-	esm->io_port = pci->base_address[0] & ~PCI_BASE_ADDRESS_SPACE;
-#endif
+	esm->io_port = pci_resource_start(pci, 0);
 
 #ifdef ESM_DDEBUG
 	snd_printk("snd_maestro_create: io: 0x%x\n", esm->io_port);
@@ -2484,10 +2478,14 @@ EXPORT_SYMBOL(snd_es1968_get_dmabuf);
 EXPORT_SYMBOL(snd_es1968_back_dmabuf);
 #endif
 
-int init_module(void)
+static int __init alsa_es1968_init(void)
 {
 	return 0;
 }
-void cleanup_module(void)
+
+static void __exit alsa_es1968_exit(void)
 {
 }
+
+module_init(alsa_es1968_init)
+module_exit(alsa_es1968_exit)
