@@ -35,26 +35,34 @@
  *  Basic I/O
  */
  
-static int snd_intel8x0_codec_semaphore(intel8x0_t *codec, int secondary)
+static int snd_intel8x0_codec_semaphore(intel8x0_t *codec, int secondary, int sched)
 {
 	signed long end_time;
 	int stat = !secondary ? ICH_PCR : ICH_SCR;
 	
-	end_time = jiffies + (HZ >> 2);
+	end_time = jiffies + 3 * (HZ >> 2);
 	do {
 		if (inl(ICHREG(codec, GLOB_STA)) & stat)
 			goto __ok;
+		if (sched) {
+			set_current_state(TASK_UNINTERRUPTIBLE);
+			schedule_timeout(1);
+		}
 	} while (end_time - (signed long)jiffies >= 0);
 	snd_printk("snd_intel8x0_codec_semaphore: codec %i is not ready [0x%x]\n", secondary, inl(ICHREG(codec, GLOB_STA)));
 	return -EIO;
 
       __ok:
-	end_time = jiffies + (HZ >> 2);
+	end_time = jiffies + 10 * (HZ >> 2);
       	do {
       		if (!(inb(ICHREG(codec, ACC_SEMA)) & ICH_CAS))
       			return 0;
+      		if (sched) {
+			set_current_state(TASK_UNINTERRUPTIBLE);
+			schedule_timeout(1);
+      		}
 	} while (end_time - (signed long)jiffies >= 0);
-	snd_printk("snd_intel8x0_codec_semaphore: codec %i semaphore is not ready [0x%x]\n", secondary, inb(ICHREG(codec, ACC_SEMA)));
+	snd_printk("snd_intel8x0_codec_semaphore: codec %i semaphore is not ready [0x%x][0x%x]\n", secondary, inb(ICHREG(codec, ACC_SEMA)), inl(ICHREG(codec, GLOB_STA)));
 	return -EIO;
 }
  
@@ -64,7 +72,7 @@ static void snd_intel8x0_codec_write(void *private_data,
 {
 	intel8x0_t *codec = (intel8x0_t *)private_data;
 	
-	snd_intel8x0_codec_semaphore(codec, 0);
+	snd_intel8x0_codec_semaphore(codec, 0, 0);
 	return outw(val, codec->port + reg);
 }
 
@@ -73,7 +81,7 @@ static unsigned short snd_intel8x0_codec_read(void *private_data,
 {
 	intel8x0_t *codec = (intel8x0_t *)private_data;
 
-	if (snd_intel8x0_codec_semaphore(codec, 0) < 0)
+	if (snd_intel8x0_codec_semaphore(codec, 0, 0) < 0)
 		return ~0;
 	return inw(codec->port + reg);
 }
@@ -710,6 +718,22 @@ static void snd_intel8x0_determine_rates(intel8x0_t *codec, int reg, unsigned in
 static int snd_intel8x0_chip_init(intel8x0_t *codec)
 {
 	unsigned short ext_id;
+	signed long end_time;
+	
+	/* ACLink on, warm reset */
+	outl(ICH_AC97WARM | ICH_AC97COLD, ICHREG(codec, GLOB_CNT));
+	end_time = jiffies + (HZ >> 2);
+	do {
+		if ((inl(ICHREG(codec, GLOB_CNT)) & ICH_AC97WARM) == 0)
+			goto __ok;
+	} while (end_time - (signed long)jiffies >= 0);
+	snd_printk("AC'97 warm reset still in progress? [0x%x]\n", inl(ICHREG(codec, GLOB_CNT)));
+
+      __ok:	
+	/* try to wait to the ready state */
+	inw(codec->port);	/* clear semaphore flag */
+	snd_intel8x0_codec_semaphore(codec, 0, 1);
+	inw(codec->port);	/* clear semaphore flag */
 
 	codec->ac97_ext_id = 
 	ext_id = snd_intel8x0_codec_read(codec, AC97_EXTENDED_ID);
@@ -767,20 +791,15 @@ int snd_intel8x0_create(snd_card_t * card,
 	codec = snd_magic_kcalloc(intel8x0_t, 0, GFP_KERNEL);
 	if (codec == NULL)
 		return -ENOMEM;
-	codec->reg_lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&codec->reg_lock);
 	codec->card = card;
 	codec->pci = pci;
 	codec->dma_pbk = dma_pbk;
 	codec->dma_cap = dma_cap;
 	codec->dma_mic = dma_mic;
 	codec->irqptr = irqptr;
-#ifdef NEW_PCI
-	codec->port = pci->resource[0].start;
-	codec->bmport = pci->resource[1].start;
-#else
-	codec->port = pci->base_address[0] & ~PCI_BASE_ADDRESS_SPACE;
-	codec->bmport = pci->base_address[1] & ~PCI_BASE_ADDRESS_SPACE;
-#endif
+	codec->port = pci_resource_start(pci, 0);
+	codec->bmport = pci_resource_start(pci, 1);
 	pci_read_config_word(pci, PCI_COMMAND, &cmdw);
 	if ((cmdw & PCI_COMMAND_IO) != PCI_COMMAND_IO) {
 		cmdw |= PCI_COMMAND_IO;
@@ -851,15 +870,14 @@ EXPORT_SYMBOL(snd_intel8x0_mixer);
  *  INIT part
  */
 
-#ifdef MODULE
-
-int __init init_module(void)
+static int __init alsa_intel8x0_init(void)
 {
 	return 0;
 }
 
-void __exit cleanup_module(void)
+static void __exit alsa_intel8x0_exit(void)
 {
 }
 
-#endif
+module_init(alsa_intel8x0_init)
+module_exit(alsa_intel8x0_exit)
