@@ -2703,9 +2703,9 @@ int snd_trident_create(snd_card_t * card,
 	if (trident == NULL)
 		return -ENOMEM;
 	trident->card = card;
-	trident->reg_lock = SPIN_LOCK_UNLOCKED;
-	trident->event_lock = SPIN_LOCK_UNLOCKED;
-	trident->voice_alloc = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&trident->reg_lock);
+	spin_lock_init(&trident->event_lock);
+	spin_lock_init(&trident->voice_alloc);
 	if (pcm_channels < 1)
 		pcm_channels = 1;
 	if (pcm_channels > 32)
@@ -2755,11 +2755,7 @@ int snd_trident_create(snd_card_t * card,
 	trident->dma3ptr = dma3ptr;
 	trident->dma4ptr = dma4ptr;
 	trident->irqptr = irqptr;
-#ifdef NEW_PCI
-	trident->port = pci->resource[0].start;
-#else
-	trident->port = pci->base_address[0] & ~PCI_BASE_ADDRESS_SPACE;
-#endif
+	trident->port = pci_resource_start(pci, 0);
 	trident->midi_port = TRID_REG(trident, T4D_MPU401_BASE);
 	pci_set_master(pci);
 	pci_read_config_word(pci, PCI_COMMAND, &cmdw);
@@ -3086,15 +3082,14 @@ EXPORT_SYMBOL(snd_trident_clear_voices);
  *  INIT part
  */
 
-#ifdef MODULE
-
-int __init init_module(void)
+static int __init alsa_trident_init(void)
 {
 	return 0;
 }
 
-void __exit cleanup_module(void)
+static void __exit alsa_trident_exit(void)
 {
 }
 
-#endif
+module_init(alsa_trident_init)
+module_exit(alsa_trident_exit)
