@@ -299,7 +299,7 @@ void snd_sb16dsp_interrupt(snd_pcm_t * pcm, unsigned short status)
 #if 0
 	PRINTK("sb16: interrupt - status = 0x%x\n", status);
 #endif
-	if (status & 0x01) {
+	if (status & SB_IRQTYPE_8BIT) {
 		ok = 0;
 		if ((codec->mode16 & (SB_MODE16_PLAYBACK16 | SB_MODE16_PLAYBACK)) == SB_MODE16_PLAYBACK) {
 			snd_pcm_transfer_done(codec->playback_subchn);
@@ -324,7 +324,7 @@ void snd_sb16dsp_interrupt(snd_pcm_t * pcm, unsigned short status)
 		snd_sb16_ack_8bit(codec);
 		spin_unlock_irqrestore(&codec->reg_lock, flags);
 	}
-	if (status & 0x02) {
+	if (status & SB_IRQTYPE_16BIT) {
 		ok = 0;
 		if ((codec->mode16 & (SB_MODE16_PLAYBACK16 | SB_MODE16_PLAYBACK)) == (SB_MODE16_PLAYBACK16 | SB_MODE16_PLAYBACK)) {
 			snd_pcm_transfer_done(codec->playback_subchn);
