@@ -28,7 +28,8 @@
 
 #ifdef MODULE_PARM
 MODULE_AUTHOR("Uros Bizjak <uros@kss-loka.si>");
-MODULE_DESCRIPTION("ALSA driver for SB16 Creative Signal Processor");
+MODULE_DESCRIPTION("ALSA driver for SB16 Creative Signal Processor\n\
+classes: {sound}");
 #endif MODULE_PARM
 
 /*
